# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _


from .forms import ContactFormSettingsForm
from .models import Contact, ContactFormSettings


class ContactAdmin(admin.ModelAdmin):
    date_hierarchy = 'creation_date'

    list_display = [
        'last_name',
        'first_name',
        'company',
        'email',
        'phone',
        'city',
        'country',
        'optin_newsletter',
        'creation_date'
    ]

    list_filter = [
        'creation_date',
        'optin_newsletter',
    ]
    search_fields = [
        'first_name',
        'last_name',
        'company',
        'email',
        'phone',
        'city',
        'state',
    ]
    fieldsets = [
        (None, {'fields': [
            'civility',
            'first_name',
            'last_name',
            'company',
        ]}),
        (None, {'fields': [
            'message',
        ]}),
        (_("Contact"), {'fields': [
            'email',
            'phone',
            'optin_newsletter',
        ]}),
        (_("Address"), {'fields': [
            'city',
            'state',
            'country',
        ]}),
        (None, {'fields': [
            'rgpd',
            'terms',
        ]}),
    ]


class ContactFormSettingsAdmin(admin.ModelAdmin):
    form = ContactFormSettingsForm

    def get_form(self, request, obj=None, **kwargs):
        form = super(ContactFormSettingsAdmin, self).get_form(
            request, obj, **kwargs)
        form.base_fields['email_to'].widget.attrs['style'] = 'width: 45em;'
        return form


try:
    from import_export.admin import ExportMixin
except ImportError:
    pass
else:
    from emencia_contact_form.resources import ContactResource
    metaclass = type(ContactAdmin)
    ContactAdmin = metaclass('ContactAdmin', (ExportMixin, ContactAdmin), {
        'resource_class': ContactResource,
    })


admin.site.register(Contact, ContactAdmin)
admin.site.register(ContactFormSettings, ContactFormSettingsAdmin)
