# coding: utf-8

from django import forms
from django.core.validators import validate_email


class MultiEmailField(forms.Field):
    def to_python(self, value):
        """Normalize data to a list of strings."""
        # Return an empty list if no input was given.
        if not value:
            return []
        # We create the list from commas, trailing ones are discarded
        return [mail.strip() for mail in value.rstrip(',').split(',')]

    def validate(self, value):
        """Check if value consists only of valid emails."""
        # Use the parent's handling of required fields, etc.
        super(MultiEmailField, self).validate(value)
        for email in value:
            validate_email(email)

    def clean(self, value):
        value = super(MultiEmailField, self).clean(value)
        return ",".join(value)
