# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.conf import settings
from django.forms import ModelForm
from django.utils.translation import ugettext_lazy as _

from .fields import MultiEmailField
from .models import Contact, ContactFormSettings


if 'captcha' in settings.INSTALLED_APPS:
    from captcha.fields import ReCaptchaField
else:
    ReCaptchaField = None


CONTACTFORM_RGPD_ENABLED = getattr(settings, 'CONTACTFORM_RGPD_ENABLED', False)
CONTACTFORM_TERMS_ENABLED = getattr(settings, 'CONTACTFORM_TERMS_ENABLED', False)


CONTACTFORM_RGPD_LABEL = getattr(settings, 'CONTACTFORM_RGPD_LABEL', _(
    'By submitting this form, I do agree that all '
    'information provided can be used to qualify my '
    'request and to provide updates on my application.'
))
CONTACTFORM_TERMS_LABEL = getattr(settings, 'CONTACTFORM_TERMS_LABEL', _(
    'By submitting this form, I do accept site terms.'
))


class ContactForm(ModelForm):
    error_css_class = 'error'
    required_css_class = 'required'

    if ReCaptchaField:
        captcha = ReCaptchaField(attrs={'theme': 'clean'})

    def __init__(self, *args, **kwargs):
        super(ContactForm, self).__init__(*args, **kwargs)

        if CONTACTFORM_RGPD_ENABLED:
            self.fields['rgpd'].label = CONTACTFORM_RGPD_LABEL
            self.fields['rgpd'].required = True

        if CONTACTFORM_TERMS_ENABLED:
            self.fields['terms'].label = CONTACTFORM_TERMS_LABEL
            self.fields['terms'].required = True

    class Meta:
        model = Contact
        fields = [
            'civility',
            'first_name',
            'last_name',
            'email',
            'message',
            'phone',
            'company',
            'city',
            'state',
            'country',
            'optin_newsletter',
        ]
        if ReCaptchaField:
            fields.append('captcha')
        if CONTACTFORM_RGPD_ENABLED:
            fields.append('rgpd')
        if CONTACTFORM_TERMS_ENABLED:
            fields.append('terms')


class ContactFormSettingsForm(ModelForm):
    email_to = MultiEmailField(
        _("Send mail to"),
        help_text=_(
            "You can specify multiple mail addresses: "
            "Separate them with a comma.")
    )

    class Meta:
        model = ContactFormSettings
        fields = [
            "site",
            "subject",
            "email_to",
            "email_from",
            "success_html",
        ]
